import React, { useState } from 'react';
import { Col, Row } from 'react-bootstrap';
import { AiOutlineClose, AiOutlinePlus } from 'react-icons/ai';

interface CollapsibleBoxProps {
  title: string;
  children: React.ReactNode;
  startCollapsed?: boolean;
  theme?: string;
}

const CollapsibleBox: React.FC<CollapsibleBoxProps> = ({ title, children, startCollapsed, theme = '' }) => {
  const [isCollapsed, setIsCollapsed] = useState(!!startCollapsed);

  let styles = { color: 'white', paddingBottom: "3px", marginTop: "3px", marginLeft: "3px", scale: "1.3" } as React.CSSProperties

  if (theme) {
    styles = { ...styles, color: 'black', fontWeight: "bold" }
  }
  return (
    <div className={`collapsible-box${theme} p-0`}>
      <Row>
        <Col>
          <h1 className="bold-caps-16pt dark-teal pt-3 ps-3">{title}</h1>
        </Col>
        <Col className='flex-grow-0 flex-shrink-1'>
          <div className={`toggle-btn${theme} p-${theme ? 3 : 2}`} onClick={() => setIsCollapsed(!isCollapsed)}>
            {isCollapsed ?
              <AiOutlinePlus style={styles} /> :
              <AiOutlineClose style={styles} />}
          </div>
        </Col>
      </Row>

      <div className={`collapsible-content${isCollapsed ? ' collapsed' : ''}`}>
        {children}
      </div>

    </div>
  );
};

export default CollapsibleBox;
