import React, { useContext } from "react";

import { WeatherMap } from "compendium/Schema";
import { getTableData, createDataLookup, getLatestData } from "compendium/helpers/dataconversion";
import DataPage from "compendium/components/DataPage";
import Filter from "compendium/components/graphing/Filter";
import { Sections } from "compendium/helpers/constants";
import { FilterSelectionContext } from "compendium/providers/FilterSelectionProvider";
import ChartContainer from "compendium/components/graphing/ChartContainer";
import { useData } from "compendium/helpers/useData";
import NrenYearTable from "compendium/components/NrenYearTable";
import titles from "compendium/titles";

function NetworkWeatherMapPage(): React.ReactElement {
    const { filterSelection, setFilterSelection } = useContext(FilterSelectionContext);
    const { data: fetchedData, nrens } = useData<WeatherMap>('/api/weather-map', setFilterSelection);

    const latestData = fetchedData ? getLatestData(fetchedData) : [];
    const selectedData = latestData.filter(data =>
        filterSelection.selectedNrens.includes(data.nren)
    );

    const dataLookup = createDataLookup(selectedData);

    const dataByYear = getTableData(dataLookup, (obj, weathermap) => {
        const has_url = !!weathermap.url
        if (has_url) {
            obj[weathermap.url] = weathermap.url
        }
    })

    const filterNode = <Filter
        filterOptions={{ availableYears: [], availableNrens: [...nrens.values()] }}
        filterSelection={filterSelection}
        setFilterSelection={setFilterSelection}
        coloredYears
    />

    return (
        <DataPage title={titles['weather-map']}
            description="This table shows the URL links to NREN websites showing weather map, if available."
            category={Sections.Network} filter={filterNode}
            data={selectedData} filename="weather_map_nrens_per_year">
            <ChartContainer>
                <NrenYearTable data={dataByYear} columnTitle="Network Weather Map" dottedBorder noDots keysAreURLs removeDecoration />
            </ChartContainer>
        </DataPage>
    );
}
export default NetworkWeatherMapPage;
