import React, { useContext } from "react";
import { Standards } from "compendium/Schema";
import { createNrenTableLookup } from "compendium/helpers/dataconversion";
import DataPage from "compendium/components/DataPage";
import Filter from "compendium/components/graphing/Filter";
import { Sections } from "compendium/helpers/constants";
import { FilterSelectionContext } from "compendium/providers/FilterSelectionProvider";
import ChartContainer from "compendium/components/graphing/ChartContainer";
import { useData } from "compendium/helpers/useData";
import PillTable from "compendium/components/PillTable";
import titles from "compendium/titles";

function CrisisManagementPage(): React.ReactElement {
    const dataField = 'crisis_management_procedure';

    const validityCheck = (data: Standards) => data[dataField] !== null;

    const { filterSelection, setFilterSelection } = useContext(FilterSelectionContext);
    const { data, years, nrens } = useData<Standards>('/api/standards', setFilterSelection, validityCheck);

    const selectedData = data.filter(data =>
        filterSelection.selectedYears.includes(data.year) && filterSelection.selectedNrens.includes(data.nren) && validityCheck(data)
    );

    const dataLookup = createNrenTableLookup(selectedData, dataField);

    const columns = [
        "Yes",
        "No",
    ]

    const columnValueMap = new Map<string, string>([
        [columns[0], "True"],
        [columns[1], "False"],
    ]);

    const filterNode = <Filter
        filterOptions={{ availableYears: [...years], availableNrens: [...nrens.values()] }}
        filterSelection={filterSelection}
        setFilterSelection={setFilterSelection}
        coloredYears
    />

    return (
        <DataPage title={titles["crisis-management"]}
            description="The table below shows whether NRENs have a formal crisis management procedure."
            category={Sections.Policy} filter={filterNode}
            data={selectedData} filename="crisis_management_nrens_per_year">
            <ChartContainer>
                <PillTable columns={columns} columnLookup={columnValueMap} dataLookup={dataLookup} />
            </ChartContainer>
        </DataPage>
    );
}
export default CrisisManagementPage;
