import React, { useContext } from "react";
import { ServiceManagement } from "compendium/Schema";
import { createNrenTableLookup } from "compendium/helpers/dataconversion";
import DataPage from "compendium/components/DataPage";
import Filter from "compendium/components/graphing/Filter";
import { Sections } from "compendium/helpers/constants";
import { FilterSelectionContext } from "compendium/providers/FilterSelectionProvider";
import ChartContainer from "compendium/components/graphing/ChartContainer";
import { useData } from "compendium/helpers/useData";
import PillTable from "compendium/components/PillTable";
import titles from "compendium/titles";

function ServiceLevelTargetsPage(): React.ReactElement {
    const { filterSelection, setFilterSelection } = useContext(FilterSelectionContext);
    const { data, years, nrens } = useData<ServiceManagement>('/api/service-management', setFilterSelection);

    const dataField = 'service_level_targets';

    const selectedData = data.filter(data =>
        filterSelection.selectedYears.includes(data.year) && filterSelection.selectedNrens.includes(data.nren) && data[dataField] !== null
    );

    const dataLookup = createNrenTableLookup(selectedData, dataField);

    const columns = [
        "Yes",
        "No",
    ]

    const columnValueMap = new Map<string, string>([
        [columns[0], "True"],
        [columns[1], "False"],
    ]);

    const filterNode = <Filter
        filterOptions={{ availableYears: [...years], availableNrens: [...nrens.values()] }}
        filterSelection={filterSelection}
        setFilterSelection={setFilterSelection}
        coloredYears
    />

    return (
        <DataPage title={titles["service-level-targets"]}
            description="The table below shows which NRENs offer Service Levels Targets for their services. 
            If NRENs have never responded to this question in the survey, they are excluded. "
            category={Sections.Policy} filter={filterNode}
            data={selectedData} filename="service_level_targets">
            <ChartContainer>
                <PillTable columns={columns} columnLookup={columnValueMap} dataLookup={dataLookup} />
            </ChartContainer>
        </DataPage>
    );
}
export default ServiceLevelTargetsPage;
