import React, { useContext } from "react";

import { ServiceOffered } from "compendium/Schema";
import {
    createCategoryMatrixLookup
} from "compendium/helpers/dataconversion";
import DataPage from "compendium/components/DataPage";
import Filter from "compendium/components/graphing/Filter";
import { Sections } from "compendium/helpers/constants";
import { FilterSelectionContext } from "compendium/providers/FilterSelectionProvider";
import ChartContainer from "compendium/components/graphing/ChartContainer";
import { useData } from "compendium/helpers/useData";
import { ScrollableMatrix } from "compendium/components/ScrollableMatrix";
import { UserCategories } from "compendium/helpers/constants";
import titles from "compendium/titles";

function ServicesOfferedPage(): React.ReactElement {
    const { filterSelection, setFilterSelection } = useContext(FilterSelectionContext);
    const { data: servicesOffered, years, nrens } = useData<ServiceOffered>('/api/services-offered', setFilterSelection);
    const selectedData = (servicesOffered).filter(data =>
        filterSelection.selectedYears.includes(data.year)
        && filterSelection.selectedNrens.includes(data.nren)
    );

    const dataLookup = createCategoryMatrixLookup(selectedData, ['service_category'], 'user_category');

    const filterNode = <Filter
        filterOptions={{ availableYears: [...years], availableNrens: [...nrens.values()] }}
        filterSelection={filterSelection}
        setFilterSelection={setFilterSelection}
    />

    const rowInfo = {
        // title for the row, and the field in the data object to look up
        "Identity/T&I": "identity",
        "Multimedia": "multimedia",
        "Professional services": "professional_services",
        "Network services": "network_services",
        "Collaboration": "collaboration",
        "Security": "security",
        "Storage and Hosting": "storage_and_hosting",
        "ISP support": "isp_support"
    };

    return (
        <DataPage title={titles["services-offered"]}
            description={<span>
                The table below shows the different types of users served by NRENs.
                Selecting the institution type will expand the detail to show the categories of services offered by NRENs,
                with a tick indicating that the NREN offers a specific category of service to the type of user.
            </span>}
            category={Sections.Policy} filter={filterNode}
            data={selectedData} filename="nren_services_offered">
            <ChartContainer>
                <ScrollableMatrix
                    dataLookup={dataLookup}
                    rowInfo={rowInfo}
                    categoryLookup={UserCategories}
                    isTickIcon
                />
            </ChartContainer>
        </DataPage>
    );
}
export default ServicesOfferedPage;
