import React, { createContext, useState, useEffect } from 'react';
import { User } from "compendium/Schema";

interface Props {
    children: React.ReactNode;
}

async function fetchUser(): Promise<User> {
    const response = await fetch('/api/user/');
    const user = await response.json();
    return user
}

const anonymousUser: User = { 'name': '', email: '', permissions: { admin: false, active: false }, id: '', nrens: [], oidc_sub: '', role: '' };

const userContext = createContext<{
    user: User;
    logout: () => void;
    setUser: React.Dispatch<React.SetStateAction<User>>;
}>({
    user: anonymousUser,
    logout: () => { },
    setUser: () => { }
});

const UserProvider: React.FC<Props> = ({ children }) => {
    const [user, setUser] = useState<User>(anonymousUser);

    async function logoutUser() {
        await fetch('/logout');
        setUser(anonymousUser);
    }

    useEffect(() => {
        fetchUser().then(user => {
            setUser(user)
        });
    }, []);

    return (
        <userContext.Provider value={{ user, logout: logoutUser, setUser }}>
            {children}
        </userContext.Provider>
    );
};

export { userContext };
export default UserProvider;