from flask import Flask
from authlib.integrations.flask_client import OAuth, FlaskOAuth2App  # type: ignore

oauth = None  # type: OAuth


def setup_oauth(app: Flask, oidc_config: dict):
    global oauth

    if oauth is not None:
        return

    oauth = OAuth(app)

    if oidc_config is None:
        return

    oauth.register(
        name='provider',
        client_id=oidc_config['client_id'],
        client_secret=oidc_config['client_secret'],
        server_metadata_url=oidc_config['server_metadata_url'],
        client_kwargs={
            'scope': ' '.join([
                'openid',
                'email',
                'profile'
            ])},
    )


def get_client() -> FlaskOAuth2App:
    return oauth.create_client('provider')
