# flake8: noqa
"""Update Service Matrix

Revision ID: 2d6614fa7363
Revises: 642d7330a00a
Create Date: 2024-12-17 14:20:37.433244

"""
from alembic import op
import sqlalchemy as sa
from collections import defaultdict

# revision identifiers, used by Alembic.
revision = '2d6614fa7363'
down_revision = '642d7330a00a'
branch_labels = None
depends_on = None


def merge_string(old, new):
    if not old:
        return new
    if not new:
        return old
    return f'{old} / {new}'


def upgrade():
    # updates the service matrix to map lambda and open-lightpath-exchange to dedicated-optical-connections

    conn = op.get_bind()

    conn.execute(
        sa.text("""INSERT INTO service (name_key, name, category, description)
                VALUES ('dedicated-optical-connections', 'Dedicated Optical Connections', 'network_services', 'Provision of dedicated optical connections to users, e.g. Layer 1 optical channels or Open Lightpath exchanges.');
                """)
    )

    nren_data = conn.execute(
        sa.text("""SELECT nren_id, year, service_key, product_name, additional_information, official_description
                FROM nren_service WHERE service_key IN ('lambda', 'open-lightpath-exchange')""")).fetchall()

    by_nren = defaultdict(lambda: defaultdict(dict))
    for row in nren_data:
        nren_id = row[0]
        year = row[1]
        service_key = row[2]
        product_name = row[3]
        additional_information = row[4]
        official_description = row[5]
        if by_nren[nren_id][year].get('service_key'):
            old_value = by_nren[nren_id][year]
            old_product_name = old_value.get('product_name')
            old_additional_information = old_value.get('additional_information')
            old_official_description = old_value.get('official_description')
            by_nren[nren_id][year] = {
                'service_key': 'dedicated-optical-connections',
                'product_name': merge_string(product_name, old_product_name),
                'additional_information': merge_string(additional_information, old_additional_information),
                'official_description': merge_string(official_description, old_official_description)
            }

        else:
            by_nren[nren_id][year] = {
                'service_key': 'dedicated-optical-connections',
                'product_name': product_name,
                'additional_information': additional_information,
                'official_description': official_description
            }

    # insert new dedicated-optical-connections rows
    for nren_id, years in by_nren.items():
        for year, data in years.items():
            conn.execute(
                sa.text("INSERT INTO nren_service (nren_id, year, service_key, product_name, additional_information, official_description) VALUES (:nren_id, :year, :service_key, :product_name, :additional_information, :official_description);").bindparams(
                    nren_id=nren_id,
                    year=year,
                    service_key=data['service_key'],
                    product_name=data['product_name'],
                    additional_information=data['additional_information'],
                    official_description=data['official_description']
                ),

            )

    # delete old lambda and open-lightpath-exchange rows
    conn.execute(
        sa.text("DELETE FROM nren_service WHERE service_key IN ('lambda', 'open-lightpath-exchange');")
    )


def downgrade():
    # downgrade not supported, as this is a destructive migration
    pass
