import contextlib
import io
import sys
from html import unescape


def int_or_none(answers_dict, key):
    if key in answers_dict:
        value = answers_dict[key]
        if isinstance(value, str):
            value = value.replace(",", ".")
        return int(answers_dict[key])
    return None


def float_or_none(answers_dict, key):
    if key in answers_dict:
        value = answers_dict[key]
        if isinstance(value, str):
            value = value.replace(",", ".")
        return float(value)
    return None


def float_or_zero(answers_dict, key):
    value = answers_dict.get(key, 0)
    if isinstance(value, str):
        value = value.replace(",", ".")
    return float(value)


def bool_or_none(answer, key=None):
    if key:
        answer = answer.get(key)
    if answer:
        return answer == "Yes"
    return None


@contextlib.contextmanager
def redirect_stdout():
    """
    redirect stdout to a StringIO object

    :return: the StringIO object
    """
    output = io.StringIO()
    old_stdout = sys.stdout
    sys.stdout = output
    yield output
    sys.stdout = old_stdout


def sanitize(value):
    """
    Escape & replace various characters that can show up in HTML input forms

    :param value: the string to escape
    :return: the escaped string
    """
    if isinstance(value, str):
        return unescape(value).replace('\u200b', '')
    elif isinstance(value, list):
        new_value = []
        for val in value:
            new_value.append(sanitize(val))
        return new_value
    elif isinstance(value, dict):
        new_value = {}
        for key, val in value.items():
            new_value[key] = sanitize(val)
        return new_value

    return value
